==> styled-bootstrap-0.1.7-1.tgz: package/lib/Pagination/PaginationItem.js <==
var _templateObject = _taggedTemplateLiteral(['\n  &:first-child {\n    ', ' {\n      margin-left: 0;\n      ', ';\n    }\n  }\n  &:last-child {\n    ', ' {\n      ', ';\n    }\n  }\n\n  ', ';\n\n  ', ';\n'], ['\n  &:first-child {\n    ', ' {\n      margin-left: 0;\n      ', ';\n    }\n  }\n  &:last-child {\n    ', ' {\n      ', ';\n    }\n  }\n\n  ', ';\n\n  ', ';\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n      ', ' {\n        z-index: 2;\n        color: ', ';\n        background-color: ', ';\n        border-color: ', ';\n      }\n    '], ['\n      ', ' {\n        z-index: 2;\n        color: ', ';\n        background-color: ', ';\n        border-color: ', ';\n      }\n    ']),
    _templateObject3 = _taggedTemplateLiteral(['\n      ', ' {\n        color: ', ';\n        pointer-events: none;\n        background-color: ', ';\n        border-color: ', ';\n      }\n    '], ['\n      ', ' {\n        color: ', ';\n        pointer-events: none;\n        background-color: ', ';\n        border-color: ', ';\n      }\n    ']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import styled, { css } from 'styled-components';
// import PropTypes from 'prop-types';

import themeProp from '../utils/src/theme';

import { borderRightRadius, borderLeftRadius } from '../utils/src/border-radius';

import PaginationLink from './PaginationLink';

import { paginationActiveColor, paginationActiveBg, paginationActiveBorderColor, paginationDisabledColor, paginationDisabledBg, paginationDisabledBorderColor } from './default-theme';

var PaginationItem = styled.li(_templateObject, PaginationLink, borderLeftRadius('0.25rem'), PaginationLink, borderRightRadius('0.25rem'), function (props) {
  return props.active && css(_templateObject2, PaginationLink, themeProp('paginationActiveColor', paginationActiveColor), themeProp('paginationActiveBg', paginationActiveBg), themeProp('paginationActiveBorderColor', paginationActiveBorderColor));
}, function (props) {
  return props.disabled && css(_templateObject3, PaginationLink, themeProp('paginationDisabledColor', paginationDisabledColor), themeProp('paginationDisabledBg', paginationDisabledBg), themeProp('paginationDisabledBorderColor', paginationDisabledBorderColor));
});

export default PaginationItem;

==> styled-bootstrap-0.1.9.tgz: package/lib/Pagination/PaginationItem.js <==
var _templateObject = _taggedTemplateLiteral(['\n  &:first-child {\n    ', ' {\n      margin-left: 0;\n      ', ';\n    }\n  }\n\n  &:last-child {\n    ', ' {\n      ', ';\n    }\n  }\n\n  ', ';\n\n  ', ';\n'], ['\n  &:first-child {\n    ', ' {\n      margin-left: 0;\n      ', ';\n    }\n  }\n\n  &:last-child {\n    ', ' {\n      ', ';\n    }\n  }\n\n  ', ';\n\n  ', ';\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n      ', ' {\n        z-index: 2;\n        color: ', ';\n        background-color: ', ';\n        border-color: ', ';\n      }\n    '], ['\n      ', ' {\n        z-index: 2;\n        color: ', ';\n        background-color: ', ';\n        border-color: ', ';\n      }\n    ']),
    _templateObject3 = _taggedTemplateLiteral(['\n      ', ' {\n        color: ', ';\n        pointer-events: none;\n        background-color: ', ';\n        border-color: ', ';\n      }\n    '], ['\n      ', ' {\n        color: ', ';\n        pointer-events: none;\n        background-color: ', ';\n        border-color: ', ';\n      }\n    ']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import styled, { css } from 'styled-components';

import themeProp from '../utils/theme';

import { borderRightRadius, borderLeftRadius } from '../utils/border-radius';

import PaginationLink from './PaginationLink';

import { paginationActiveColor, paginationActiveBg, paginationActiveBorderColor, paginationDisabledColor, paginationDisabledBg, paginationDisabledBorderColor } from './default-theme';

var PaginationItem = styled.li(_templateObject, PaginationLink, borderLeftRadius('0.25rem'), PaginationLink, borderRightRadius('0.25rem'), function (props) {
  return props.active && css(_templateObject2, PaginationLink, themeProp('paginationActiveColor', paginationActiveColor), themeProp('paginationActiveBg', paginationActiveBg), themeProp('paginationActiveBorderColor', paginationActiveBorderColor));
}, function (props) {
  return props.disabled && css(_templateObject3, PaginationLink, themeProp('paginationDisabledColor', paginationDisabledColor), themeProp('paginationDisabledBg', paginationDisabledBg), themeProp('paginationDisabledBorderColor', paginationDisabledBorderColor));
});

export default PaginationItem;
